==> dl.php?src=linea21_2_3_0.zip: linea21/languages/es/lang_sdi.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['sdi']['name']="indicador";
$lang['sdi']['confirm_add'] = "Indicador añadido correctamente";
$lang['sdi']['confirm_mod'] = "Indicador actualizado correctamente";
$lang['sdi']['confirm_clone'] = "Indicador clonado correctamente";
$lang['sdi']['confirm_sup'] ="Indicador eliminado correctamente";


$lang['sdi']['p_name']="proveedor";
$lang['sdi']['p_confirm_mod'] = "Proveedor añadido correctamente";
$lang['sdi']['p_confirm_sup'] ="Proveedor eliminado correctamente";


$lang['sdi']['r_name']="reglas";
$lang['sdi']['r_confirm_mod'] = "Reglas añadidas correctamente";
$lang['sdi']['r_confirm_sup'] ="Reglas eliminadas correctamente";


$lang['sdi']['e_name']="evaluación";
$lang['sdi']['e_confirm_mod'] = "Evaluación añadida correctamente";
$lang['sdi']['e_confirm_sup'] ="Evaluación eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['sdi']['add']= "Añadir nuevo ".$lang['sdi']['name'];


$lang['sdi']['mod']= "Editar información global";
$lang['sdi']['clone']= "Clonar indicador";
$lang['sdi']['sup']= "Eliminar ".$lang['sdi']['name'];


$lang['sdi']['mod_e']= "Editar ".$lang['sdi']['e_name'];
$lang['sdi']['sup_e']= "Eliminar ".$lang['sdi']['e_name'];


$lang['sdi']['mod_p']= "Editar ".$lang['sdi']['p_name'];
$lang['sdi']['sup_p']= "Eliminar ".$lang['sdi']['p_name'];


$lang['sdi']['mod_r']= "Editar ".$lang['sdi']['r_name'];
$lang['sdi']['sup_r']= "Eliminar ".$lang['sdi']['r_name'];


$lang['sdi']['det']= ucfirst($lang['sdi']['name']) . " detalles";
$lang['sdi']['list']= "Ver indicadores";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['sdi']['add_title1']="Añadir información global del nuevo ".$lang['sdi']['name'];
$lang['sdi']['add_title2']="Añadir criterios de evaluación del nuevo ".$lang['sdi']['name'];
$lang['sdi']['add_title3']="Añadir información de contacto del proveedor del nuevo ".$lang['sdi']['name'];
$lang['sdi']['add_title4']="Añadir reglas del nuevo ".$lang['sdi']['name'];


$lang['sdi']['mod_title']="Editar información global del ";
$lang['sdi']['mod_title2']="Editar criterios de evaluación del ";
$lang['sdi']['mod_title3']="Editar información de contacto del proveedor del ";
$lang['sdi']['mod_title4']="Editar reglas del ";


$lang['sdi']['recap_commment']="sin comentarios";
$lang['sdi']['confirmation']="subscripción confirmada";




/*	nommage étapes add
 *  	*/


$lang['sdi']['add_step1']="información global";
$lang['sdi']['add_step2']="evaluación";
$lang['sdi']['add_step3']="proveedor";
$lang['sdi']['add_step4']="reglas";
$lang['sdi']['btn_step1']="paso 2";
$lang['sdi']['btn_step2']="paso 3";
$lang['sdi']['btn_step3']="paso 4";
$lang['sdi']['btn_fin']="¡finalizar ahora!";


/*	nommage rubrique sup
 *  	*/
$lang['sdi']['sup_sdi_warning']="¿Está usted seguro de que desea eliminar este ".$lang['sdi']['name']." ?";
$lang['sdi']['sup_sdi_warning2']="Si elimina este indicador, también se eliminarán su proveedor, reglas, valores y criterios de evaluación";
$lang['sdi']['sup_sdi_warning3']="Atención, antes de eliminar el indicador debe vaciar el área asociada a él";
/*	nommage élément rubrique
 *  	*/

$lang['sdi']['name2']="nombre";
$lang['sdi']['type']="tipo de indicador";
$lang['sdi']['value_type']="tipo de valor";
$lang['sdi']['dashboard_viz']="tipo de visualización - panel";
$lang['sdi']['detail_viz']="tipo de visualización - detalle";
$lang['sdi']['description']="descripción";
$lang['sdi']['comment']="comentarios";
$lang['sdi']['level']="nivel";
$lang['sdi']['range']="rango";
$lang['sdi']['goal']="objetivos (metas)";
$lang['sdi']['consulting']="propuestas de mejora";
$lang['sdi']['attached_to_dashboard']="Indicador estratégico";
$lang['sdi']['not_attached_to_dashboard']="Indicador no estratégico";
$lang['sdi']['info_mesure']="información de medida";
$lang['sdi']['unit']="unidad de medida";
$lang['sdi']['max_value']="máximo";
$lang['sdi']['min_value']="mínimo";
$lang['sdi']['initial_threshold_value']="umbral inicial";
$lang['sdi']['threshold_value']="umbral";
$lang['sdi']['threshold_relative']="comportamiento respecto al umbral";
$lang['sdi']['threshold_relative_comment']="Marque la casilla si el objetivo es alcanzar un valor superior al umbral.";
$lang['sdi']['threshold_relative_Y']="el objetivo es alcanzar valores superiores al umbral";
$lang['sdi']['threshold_relative_N']="el objetivo no se cumple para valores superiores al umbral.";
$lang['sdi']['frequency']="frecuencia de recogida (días)";

$lang['sdi']['bool_indicator']='Indicador de tipo booleano.';
$lang['sdi']['boolindicator_notice']='Indicador de tipo <strong>booleano</strong>. Defina una máscara utilizando la siguiente sintaxis <strong>{0=no;1=si}</strong> en el campo <a href=\"%s\">comentario</a>';
$lang['sdi']['qualindicator_notice']='Indicador de tipo <strong>cualitativo</strong>. Defina una máscara utilizando la siguiente sintaxis <strong>{0=bajo;1=medio;2=alto}</strong> en el campo <a href=\"%s\">comentario</a>.';
$lang['sdi']['boolindicator_mask']='La siguiente máscara ha sido definida : %s.';
$lang['sdi']['boolindicator_nomask']='Sin máscara definida.';

$lang['sdi']['e_title']="Criterios de evaluación de los datos";
$lang['sdi']['e_scale_compare']="comparabilidad";
$lang['sdi']['e_fiability']="fiabilidad";
$lang['sdi']['e_accessibility']="accesibilidad";
$lang['sdi']['e_lisibility']="fácil interpretación";
$lang['sdi']['e_relevance']="relevancia";
$lang['sdi']['e_global_performance']="rendimiento global";


$lang['sdi']['p_title']="proveedor de los datos";
$lang['sdi']['p_name']="nombre";
$lang['sdi']['p_service']="servicio";
$lang['sdi']['p_description']="descripción";
$lang['sdi']['p_incharge']="cargo";
$lang['sdi']['p_address']="dirección";
$lang['sdi']['p_phone']="teléfono";
$lang['sdi']['p_fax']="fax";
$lang['sdi']['p_email']="email";


$lang['sdi']['r_title']="reglas de referencia";
$lang['sdi']['r_body']="texto regulador";
$lang['sdi']['r_referer_uri']="enlace (url)";
$lang['sdi']['r_mask_uri']="enlace (texto a mostrar)";

/** select-box option and values (keys) */
$lang['sdi']['select_type']['quantitative']='cuantitativo';
$lang['sdi']['select_type']['boolean']='booleano';
$lang['sdi']['select_type']['qualitative']='cualitativo';
$lang['sdi']['select_value_type']['unique']='único';
$lang['sdi']['select_value_type']['multiple']='múltiple';
$lang['sdi']['select_dashboard_viz']['raw']='valor bruto';
$lang['sdi']['select_dashboard_viz']['gauge']='evaluación';
$lang['sdi']['select_dashboard_viz']['sparkline']='minigráfico';
$lang['sdi']['select_detail_viz']['column']='columna';
$lang['sdi']['select_detail_viz']['line']='línea';
$lang['sdi']['select_detail_viz']['area']='área';

/*	nommage quickbox
 *  	*/
$lang['sdi']['qb_add_title']=" indicadores añadidos recientemente";
$lang['sdi']['qb_mod_title']=" indicadores modificados recientemente";


/*	divers
 *  	*/
$lang['sdi']['select_choice']="-- Seleccionar de la lista --";
$lang['sdi']['facultatif']="Opcional";
$lang['sdi']['notlevel']="Nivel es requerido";
$lang['sdi']['aff_sdi_e']="Mostrar criterios de evaluación";
$lang['sdi']['modify_sdi_e']="Editar criterios de evaluación";

$lang['sdi']['aff_sdi_r']="Mostrar reglas";
$lang['sdi']['modify_sdi_r']="Editar reglas";
$lang['sdi']['aff_sdi_p']="Mostrar información del proveedor";
$lang['sdi']['modify_sdi_p']="Editar información del proveedor";
$lang['sdi']['noresultp']="Añadir un nuevo proveedor haciendo clic en el icono 'añadir proveedor'";
$lang['sdi']['noresultr']="Añadir una nueva regla haciendo clic en el icono 'añadir regla'";
$lang['sdi']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['sdi']['clone_suffix']= "clon";
$lang['sdi']['clone_confirmation']= "¿Está usted seguro de clonar este indicador?";
$lang['sdi']['see_values']="Ver valores";
/*	messages
 *  	*/


$lang['sdi']['object_notname']="El nombre es requerido.";
$lang['sdi']['object_notdescription']="La descripción es requerida.";
$lang['sdi']['object_notlevel']="El nivel es requerido.";
$lang['sdi']['object_notrange']="El rango es requerido.";
$lang['sdi']['object_notunit']="Las unidades son requeridas.";
$lang['sdi']['object_notmax_value']="El máximo debe ser un valor numérico.";
$lang['sdi']['object_notmin_value']="El mínimo debe ser un valor numérico.";
$lang['sdi']['object_notthreshold_value']="El umbral debe ser un valor numérico.";
$lang['sdi']['object_noqualboolmask']="Un indicador cualitativo o booleano ha sido definido. Ingrese una máscara en el campo 'comentario' con la sintaxis siguiente : <em>{0=value A;1=value B}</em>";
$lang['sdi']['object_notfrequency']="La frecuencia debe ser un valor numérico.";
$lang['sdi']['server_noresponse']='Error en la url: no hay respuesta del servidor, por favor revise la sintaxis';




$lang['sdi']['object_note_scale_compare']="La comparabilidad debe ser un valor numérico.";
$lang['sdi']['object_note_fiability']="La fiabilidad debe ser un valor numérico.";
$lang['sdi']['object_note_accessibility']="La accesibilidad debe ser un valor numérico.";
$lang['sdi']['object_note_lisibility']="La fácil interpretación debe ser un valor numérico.";
$lang['sdi']['object_note_relevance']="La relevancia debe ser un valor numérico.";
$lang['sdi']['object_note_global_performance']="El rendimiento global debe ser un valor numérico.";




$lang['sdi']['object_notp_name']="El nombre del proveedor es requerido";
$lang['sdi']['object_notp_address']="La dirección es es requerida";
$lang['sdi']['object_notp_phone']="El número de teléfono no es válido";
$lang['sdi']['object_notp_fax']="El número de fax no es válido";
$lang['sdi']['object_notp_mail']="El email no es válido";


$lang['sdi']['object_notr_title']="Las reglas de referencia son requeridas";
$lang['sdi']['object_notr_body']="El texto regulador es requerido";


/*	rubrique d'aide
 *  	*/
$lang['sdi']['help_add1']="Para añadir un nuevo indicador, inserte la información requerida en el formulario.";
$lang['sdi']['help_add2']="Para añadir un nuevo indicador debe realizar cuatro pasos: información global -> evaluación -> proveedor -> reglas";
$lang['sdi']['help_add3']="Completado el formulario, revise los valores en el resumen.";
$lang['sdi']['help_add4']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';
$lang['sdi']['help_add5']="Para acceder al resumen y a la pantalla de entrada rápida de datos, haga clic en '".$lang['sdi']['btn_fin']."' ";
$lang['sdi']['help_add6']="Los campos con asterisco son obligatorios.";


$lang['sdi']['help_list1']="Para más información haga clic en el nombre del indicador.";
$lang['sdi']['help_list2']="Para eliminar un indicador, haga clic en el icono 'eliminar indicador'.";
$lang['sdi']['help_list3']="Para editar un indicador, haga clic en el icono 'editar indicador'.";
$lang['sdi']['help_list4']="Para añadir un nuevo indicador, haga clic en 'añadir nuevo indicador'.";
$lang['sdi']['help_list5']="Si desea realizar una búsqueda dentro del módulo 'indicadores', haga clic en 'buscar'.";

$lang['sdi']['help_mod1']="Para editar la información global, inserte la información requerida en el formulario.";
$lang['sdi']['help_mod2']="Completado el formulario, revise los valores en el resumen.";
$lang['sdi']['help_mod3']="Validado el resumen, haga clic en 'revisar valores' si desea realizar cambios.";
$lang['sdi']['help_mod4']="Para editar información del proveedor, reglas y criterios de evaluación, haga clic  en el icono correspondiente situado al final del formulario.";
$lang['sdi']['help_mod5']="Para editar información global, haga clic en el icono que aparece en la página de detalles del indicador.";


$lang['sdi']['help_mod_p1']="Para editar los datos del proveedor, inserte la información requerida en el formulario.";
$lang['sdi']['help_mod_e1']="Para editar los criterios de evaluación, inserte la información requerida en el formulario.";
$lang['sdi']['help_mod_r1']="Para editar las reglas, inserte la información requerida en el formulario.";


$lang['sdi']['help_det1']="Para editar la información global, haga clic en el icono 'editar información global'.";
$lang['sdi']['help_det2']="Para eliminar un indicador haga clic en el icono 'eliminar indicador'.";
$lang['sdi']['help_det3']="Para mas información sobre un nivel, haga clic en el nivel del indicador.";
$lang['sdi']['help_det4']="Para ver información sobre el proveedor, reglas y evaluación, haga clic en el icono correspondiente situado al final del formulario.";
$lang['sdi']['help_det5']="Para editar información sobre el proveedor, las reglas y evaluación, haga clic en el icono correspondiente.";


$lang['sdi']['help_sup1']="Si esta seguro de que desea eliminar el indicador y valores asociados (proveedores, reglas, criterios de evaluación) haga clic en 'validar'";
$lang['sdi']['help_sup2']="Si al eliminar un indicador el nivel correspondiente no esta vacía, le aparecerá un mensaje de aviso";
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/es/lang_sdi.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['sdi']['name']="indicador";
$lang['sdi']['confirm_add'] = "Indicador añadido correctamente";
$lang['sdi']['confirm_mod'] = "Indicador actualizado correctamente";
$lang['sdi']['confirm_clone'] = "Indicador clonado correctamente";
$lang['sdi']['confirm_sup'] ="Indicador eliminado correctamente";


$lang['sdi']['p_name']="proveedor";
$lang['sdi']['p_confirm_mod'] = "Proveedor añadido correctamente";
$lang['sdi']['p_confirm_sup'] ="Proveedor eliminado correctamente";


$lang['sdi']['r_name']="reglas";
$lang['sdi']['r_confirm_mod'] = "Reglas añadidas correctamente";
$lang['sdi']['r_confirm_sup'] ="Reglas eliminadas correctamente";


$lang['sdi']['e_name']="evaluación";
$lang['sdi']['e_confirm_mod'] = "Evaluación añadida correctamente";
$lang['sdi']['e_confirm_sup'] ="Evaluación eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['sdi']['add']= "Añadir nuevo ".$lang['sdi']['name'];


$lang['sdi']['mod']= "Editar información global";
$lang['sdi']['clone']= "Clonar indicador";
$lang['sdi']['sup']= "Eliminar ".$lang['sdi']['name'];


$lang['sdi']['mod_e']= "Editar ".$lang['sdi']['e_name'];
$lang['sdi']['sup_e']= "Eliminar ".$lang['sdi']['e_name'];


$lang['sdi']['mod_p']= "Editar ".$lang['sdi']['p_name'];
$lang['sdi']['sup_p']= "Eliminar ".$lang['sdi']['p_name'];


$lang['sdi']['mod_r']= "Editar ".$lang['sdi']['r_name'];
$lang['sdi']['sup_r']= "Eliminar ".$lang['sdi']['r_name'];


$lang['sdi']['det']= ucfirst($lang['sdi']['name']) . " detalles";
$lang['sdi']['list']= "Ver indicadores";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['sdi']['add_title1']="Añadir información global del nuevo ".$lang['sdi']['name'];
$lang['sdi']['add_title2']="Añadir criterios de evaluación del nuevo ".$lang['sdi']['name'];
$lang['sdi']['add_title3']="Añadir información de contacto del proveedor del nuevo ".$lang['sdi']['name'];
$lang['sdi']['add_title4']="Añadir reglas del nuevo ".$lang['sdi']['name'];


$lang['sdi']['mod_title']="Editar información global del ";
$lang['sdi']['mod_title2']="Editar criterios de evaluación del ";
$lang['sdi']['mod_title3']="Editar información de contacto del proveedor del ";
$lang['sdi']['mod_title4']="Editar reglas del ";


$lang['sdi']['recap_commment']="sin comentarios";
$lang['sdi']['confirmation']="subscripción confirmada";




/*	nommage étapes add
 *  	*/


$lang['sdi']['add_step1']="información global";
$lang['sdi']['add_step2']="evaluación";
$lang['sdi']['add_step3']="proveedor";
$lang['sdi']['add_step4']="reglas";
$lang['sdi']['btn_step1']="paso 2";
$lang['sdi']['btn_step2']="paso 3";
$lang['sdi']['btn_step3']="paso 4";
$lang['sdi']['btn_fin']="¡finalizar ahora!";


/*	nommage rubrique sup
 *  	*/
$lang['sdi']['sup_sdi_warning']="¿Está usted seguro de que desea eliminar este ".$lang['sdi']['name']." ?";
$lang['sdi']['sup_sdi_warning2']="Si elimina este indicador, también se eliminarán su proveedor, reglas, valores y criterios de evaluación";
$lang['sdi']['sup_sdi_warning3']="Atención, antes de eliminar el indicador debe vaciar el área asociada a él";
/*	nommage élément rubrique
 *  	*/

$lang['sdi']['name2']="nombre";
$lang['sdi']['type']="tipo de indicador";
$lang['sdi']['nature']="indicator nature"; // @todo translation
$lang['sdi']['value_type']="tipo de valor";
$lang['sdi']['dashboard_viz']="tipo de visualización - panel";
$lang['sdi']['detail_viz']="tipo de visualización - detalle";
$lang['sdi']['description']="descripción";
$lang['sdi']['comment']="comentarios";
$lang['sdi']['level']="nivel";
$lang['sdi']['range']="rango";
$lang['sdi']['goal']="objetivos (metas)";
$lang['sdi']['consulting']="propuestas de mejora";
$lang['sdi']['attached_to_dashboard']="Indicador estratégico";
$lang['sdi']['not_attached_to_dashboard']="Indicador no estratégico";
$lang['sdi']['info_mesure']="información de medida";
$lang['sdi']['unit']="unidad de medida";
$lang['sdi']['max_value']="máximo";
$lang['sdi']['min_value']="mínimo";
$lang['sdi']['initial_threshold_value']="umbral inicial";
$lang['sdi']['threshold_value']="umbral";
$lang['sdi']['threshold_relative']="comportamiento respecto al umbral";
$lang['sdi']['threshold_relative_comment']="Marque la casilla si el objetivo es alcanzar un valor superior al umbral.";
$lang['sdi']['threshold_relative_Y']="el objetivo es alcanzar valores superiores al umbral";
$lang['sdi']['threshold_relative_N']="el objetivo no se cumple para valores superiores al umbral.";
$lang['sdi']['frequency']="frecuencia de recogida (días)";

$lang['sdi']['bool_indicator']='Indicador de tipo booleano.';
$lang['sdi']['multipleindicator_notice']='Multiple indicator. Pre-define fields labels using the following syntax <strong>{heat;electricity;fuel}</strong> in the<a href=\"%s\">comment</a> field'; // @todo translation
$lang['sdi']['boolindicator_notice']='Indicador de tipo <strong>booleano</strong>. Defina una máscara utilizando la siguiente sintaxis <strong>{0=no;1=si}</strong> en el campo <a href=\"%s\">comentario</a>';
$lang['sdi']['qualindicator_notice']='Indicador de tipo <strong>cualitativo</strong>. Defina una máscara utilizando la siguiente sintaxis <strong>{0=bajo;1=medio;2=alto}</strong> en el campo <a href=\"%s\">comentario</a>.';
$lang['sdi']['boolindicator_mask']='La siguiente máscara ha sido definida : %s.';
$lang['sdi']['boolindicator_nomask']='Sin máscara definida.';

$lang['sdi']['e_title']="Criterios de evaluación de los datos";
$lang['sdi']['e_scale_compare']="comparabilidad";
$lang['sdi']['e_fiability']="fiabilidad";
$lang['sdi']['e_accessibility']="accesibilidad";
$lang['sdi']['e_lisibility']="fácil interpretación";
$lang['sdi']['e_relevance']="relevancia";
$lang['sdi']['e_global_performance']="rendimiento global";


$lang['sdi']['p_title']="proveedor de los datos";
$lang['sdi']['p_name']="nombre";
$lang['sdi']['p_service']="servicio";
$lang['sdi']['p_description']="descripción";
$lang['sdi']['p_incharge']="cargo";
$lang['sdi']['p_address']="dirección";
$lang['sdi']['p_phone']="teléfono";
$lang['sdi']['p_fax']="fax";
$lang['sdi']['p_email']="email";


$lang['sdi']['r_title']="reglas de referencia";
$lang['sdi']['r_body']="texto regulador";
$lang['sdi']['r_referer_uri']="enlace (url)";
$lang['sdi']['r_mask_uri']="enlace (texto a mostrar)";

/** select-box option and values (keys) */
// $lang['sdi']['select_type']['pressure']='pressure';  // @todo translation
// $lang['sdi']['select_type']['state']='state';  // @todo translation
// $lang['sdi']['select_type']['response']='response';  // @todo translation
$lang['sdi']['select_type']['not-set']='not set';  // @todo translation
$lang['sdi']['select_type']['follow-up']='follow-up';   // @todo translation
$lang['sdi']['select_type']['achievement']='achievement';  // @todo translation
$lang['sdi']['select_nature']['quantitative']='cuantitativo';
$lang['sdi']['select_nature']['boolean']='booleano';
$lang['sdi']['select_nature']['qualitative']='cualitativo';
$lang['sdi']['select_value_type']['unique']='único';
$lang['sdi']['select_value_type']['multiple']='múltiple';
$lang['sdi']['select_dashboard_viz']['raw']='valor bruto';
$lang['sdi']['select_dashboard_viz']['gauge']='evaluación';
$lang['sdi']['select_dashboard_viz']['sparkline']='minigráfico';
$lang['sdi']['select_detail_viz']['column']='columna';
$lang['sdi']['select_detail_viz']['line']='línea';
$lang['sdi']['select_detail_viz']['area']='área';

/*	nommage quickbox
 *  	*/
$lang['sdi']['qb_add_title']=" indicadores añadidos recientemente";
$lang['sdi']['qb_mod_title']=" indicadores modificados recientemente";


/*	divers
 *  	*/
$lang['sdi']['select_choice']="-- Seleccionar de la lista --";
$lang['sdi']['facultatif']="Opcional";
$lang['sdi']['notlevel']="Nivel es requerido";
$lang['sdi']['aff_sdi_e']="Mostrar criterios de evaluación";
$lang['sdi']['modify_sdi_e']="Editar criterios de evaluación";

$lang['sdi']['aff_sdi_r']="Mostrar reglas";
$lang['sdi']['modify_sdi_r']="Editar reglas";
$lang['sdi']['aff_sdi_p']="Mostrar información del proveedor";
$lang['sdi']['modify_sdi_p']="Editar información del proveedor";
$lang['sdi']['noresultp']="Añadir un nuevo proveedor haciendo clic en el icono 'añadir proveedor'";
$lang['sdi']['noresultr']="Añadir una nueva regla haciendo clic en el icono 'añadir regla'";
$lang['sdi']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['sdi']['clone_suffix']= "clon";
$lang['sdi']['clone_confirmation']= "¿Está usted seguro de clonar este indicador?";
$lang['sdi']['see_values']="Ver valores";
/*	messages
 *  	*/


$lang['sdi']['object_notname']="El nombre es requerido.";
$lang['sdi']['object_notdescription']="La descripción es requerida.";
$lang['sdi']['object_notlevel']="El nivel es requerido.";
$lang['sdi']['object_notrange']="El rango es requerido.";
$lang['sdi']['object_notunit']="Las unidades son requeridas.";
$lang['sdi']['object_notmax_value']="El máximo debe ser un valor numérico.";
$lang['sdi']['object_notmin_value']="El mínimo debe ser un valor numérico.";
$lang['sdi']['object_notthreshold_value']="El umbral debe ser un valor numérico.";
$lang['sdi']['object_noqualboolmask']="Un indicador cualitativo o booleano ha sido definido. Ingrese una máscara en el campo 'comentario' con la sintaxis siguiente : <em>{0=value A;1=value B}</em>";
$lang['sdi']['object_notfrequency']="La frecuencia debe ser un valor numérico.";
$lang['sdi']['server_noresponse']='Error en la url: no hay respuesta del servidor, por favor revise la sintaxis';




$lang['sdi']['object_note_scale_compare']="La comparabilidad debe ser un valor numérico.";
$lang['sdi']['object_note_fiability']="La fiabilidad debe ser un valor numérico.";
$lang['sdi']['object_note_accessibility']="La accesibilidad debe ser un valor numérico.";
$lang['sdi']['object_note_lisibility']="La fácil interpretación debe ser un valor numérico.";
$lang['sdi']['object_note_relevance']="La relevancia debe ser un valor numérico.";
$lang['sdi']['object_note_global_performance']="El rendimiento global debe ser un valor numérico.";




$lang['sdi']['object_notp_name']="El nombre del proveedor es requerido";
$lang['sdi']['object_notp_address']="La dirección es es requerida";
$lang['sdi']['object_notp_phone']="El número de teléfono no es válido";
$lang['sdi']['object_notp_fax']="El número de fax no es válido";
$lang['sdi']['object_notp_mail']="El email no es válido";


$lang['sdi']['object_notr_title']="Las reglas de referencia son requeridas";
$lang['sdi']['object_notr_body']="El texto regulador es requerido";


/*	rubrique d'aide
 *  	*/
$lang['sdi']['help_add1']="Para añadir un nuevo indicador, inserte la información requerida en el formulario.";
$lang['sdi']['help_add2']="Para añadir un nuevo indicador debe realizar cuatro pasos: información global -> evaluación -> proveedor -> reglas";
$lang['sdi']['help_add3']="Completado el formulario, revise los valores en el resumen.";
$lang['sdi']['help_add4']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';
$lang['sdi']['help_add5']="Para acceder al resumen y a la pantalla de entrada rápida de datos, haga clic en '".$lang['sdi']['btn_fin']."' ";
$lang['sdi']['help_add6']="Los campos con asterisco son obligatorios.";


$lang['sdi']['help_list1']="Para más información haga clic en el nombre del indicador.";
$lang['sdi']['help_list2']="Para eliminar un indicador, haga clic en el icono 'eliminar indicador'.";
$lang['sdi']['help_list3']="Para editar un indicador, haga clic en el icono 'editar indicador'.";
$lang['sdi']['help_list4']="Para añadir un nuevo indicador, haga clic en 'añadir nuevo indicador'.";
$lang['sdi']['help_list5']="Si desea realizar una búsqueda dentro del módulo 'indicadores', haga clic en 'buscar'.";

$lang['sdi']['help_mod1']="Para editar la información global, inserte la información requerida en el formulario.";
$lang['sdi']['help_mod2']="Completado el formulario, revise los valores en el resumen.";
$lang['sdi']['help_mod3']="Validado el resumen, haga clic en 'revisar valores' si desea realizar cambios.";
$lang['sdi']['help_mod4']="Para editar información del proveedor, reglas y criterios de evaluación, haga clic  en el icono correspondiente situado al final del formulario.";
$lang['sdi']['help_mod5']="Para editar información global, haga clic en el icono que aparece en la página de detalles del indicador.";


$lang['sdi']['help_mod_p1']="Para editar los datos del proveedor, inserte la información requerida en el formulario.";
$lang['sdi']['help_mod_e1']="Para editar los criterios de evaluación, inserte la información requerida en el formulario.";
$lang['sdi']['help_mod_r1']="Para editar las reglas, inserte la información requerida en el formulario.";


$lang['sdi']['help_det1']="Para editar la información global, haga clic en el icono 'editar información global'.";
$lang['sdi']['help_det2']="Para eliminar un indicador haga clic en el icono 'eliminar indicador'.";
$lang['sdi']['help_det3']="Para mas información sobre un nivel, haga clic en el nivel del indicador.";
$lang['sdi']['help_det4']="Para ver información sobre el proveedor, reglas y evaluación, haga clic en el icono correspondiente situado al final del formulario.";
$lang['sdi']['help_det5']="Para editar información sobre el proveedor, las reglas y evaluación, haga clic en el icono correspondiente.";


$lang['sdi']['help_sup1']="Si esta seguro de que desea eliminar el indicador y valores asociados (proveedores, reglas, criterios de evaluación) haga clic en 'validar'";
$lang['sdi']['help_sup2']="Si al eliminar un indicador el nivel correspondiente no esta vacía, le aparecerá un mensaje de aviso";
?>
